==> vod-api-model-1.0.2-sources.jar: com/valor/vod/api/model/constant/response/HttpCode2.java <==
package com.valor.vod.api.model.constant.response;

/** mfc vms http status code Created by Frank.Huang on 2016/7/5. */
public class HttpCode2 {

    // return http code
    public static final int SERVER_ERROR = 555; // Server error

    public static final int SYS_CODE_AUTH = 2;
    public static final int SYS_CODE_META = 1001;
    public static final int SYS_CODE_CLOUD = 1002;
    public static final int SYS_CODE_ACCOUNT = 1003;

    public static final int SYS_CODE_PROFILE = 1005;
    public static final int SYS_CODE_CC = 1006;
    public static final int SYS_CODE_CLOUD_PKG_WEB = 1007;
    public static final int SYS_CODE_FLOW_CONTROL = 1008;
    public static final int SYS_CODE_DAC = 1009;
    public static final int SYS_CODE_LAC = 1010;
    public static final int SYS_CODE_MEMBER_WEB = 1011;
    public static final int SYS_CODE_ADMIN_SERVER = 1012;
    public static final int SYS_CODE_ACTIVITY = 1013;
    public static final int SYS_CODE_3RD_PROXY = 1014;
    public static final int SYS_CODE_MUSES = 1015;

    public static final int SYS_CODE_OAUTH2_SERVER = 2000;

    public static final int OK = 0;

    public static final int RET_SYS_EXCEPTION = 1; // 系统异常
    public static final int RET_UNAUTHORIZED = 2; // 未授权
    public static final int RET_INVALID_PARAM = 3; // 无效的参数
    public static final int RET_DATA_EXCEPTION = 4; // 数据异常
    public static final int RET_INVALID_USER = 5; // 无效的用户
    public static final int RET_UNSUPPORTED_VERSION = 6; // 不支持的版本
    public static final int RET_CLOUD_ERR = 7; // 网盘操作错误
    public static final int RET_USER_BIZ = 8; // 用户业务
    public static final int RET_BIZ_ERR = 9; // 业务
    public static final int RET_UC_USER = 10;

    // error code
    public static final int ERR_NO_DATA = 100;
    public static final int ERR_SYS_EXCEPTION = 101;
    public static final int ERR_INVALID_USER = 102;
    public static final int ERR_RESULT_NOT_UNIQUE = 103;
    public static final int ERR_ES_EXCEPTION = 104;
    public static final int ERR_ENCRYPT_MSG = 105;
    public static final int ERR_CALL_API_ERROR = 106; // 调用API接口失败
    public static final int ERR_SYS_SERVICE_NOTAVALIABLE = 107;
    public static final int ERR_SYS_IO_EXCEPTION = 108;
    public static final int ERR_SYS_API_ERROR = 109;

    public static final int ERR_AUTH_TOKEN_IS_EMPTY = 200;
    public static final int ERR_AUTH_INVALID_TOKEN = 201;
    public static final int ERR_AUTH_INVALID_DID = 202;
    public static final int ERR_AUTH_EXPIRED_TOKEN = 203;
    public static final int ERR_AUTH_UNREGISTERED_DID = 204;
    public static final int ERR_AUTH_UID_CONFLICT = 205;
    public static final int ERR_AUTH_USER_STATUS_EXCEPTION = 206;
    public static final int ERR_AUTH_INVALID_AS_PRIVATE_KEY = 207;
    public static final int ERR_AUTH_INVALID_TOKEN_TO_OBJECT = 208;
    public static final int ERR_AUTH_INVALID_APPID = 220;
    public static final int ERR_AUTH_INVALID_APPVER = 221;
    public static final int ERR_AUTH_DID_LOGIN_DISABLE = 222;
    public static final int ERR_AUTH_ACCOUNT_ID_CONFLICT = 223;
    public static final int ERR_AUTH_REGION_FORBIDDEN = 224;
    public static final int ERR_AUTH_CURRENT_ACCOUNT_ALREADY_OFFLINE = 225; // 当前用户已下线
    public static final int ERR_AUTH_QUERY_LOGIN_METHOD_FAILURE = 226; //
    public static final int ERR_AUTH_LOGIN_CODE_ALREADY_USED = 227; //
    public static final int ERR_AUTH_LOGIN_DEVICE_UNAUTHORIZED = 228; //

    public static final int ERR_EMAIL_BINDING_FAILED = 230;

    public static final int ERR_AUTH_VERIFICATION_CODE_IS_EMPTY = 240;
    public static final int ERR_AUTH_INVALID_PHONE_NUMBER = 241;
    public static final int ERR_AUTH_PHONE_NUMBER_IS_EMPTY = 242;
    public static final int ERR_AUTH_LOGIN_ID_CONFLICT = 243;
    public static final int ERR_AUTH_SLIDER_VERIFICATION_FAILED = 244;

    public static final int ERR_PARAM_INVALID = 250;
    public static final int ERR_PARAM_ID_IS_EMPTY = 251;
    public static final int ERR_PARAM_UPLOAD_ERROR = 252;

    public static final int ERR_PARAM_UNSUPPORTED_CHANNEL_ERROR = 260;
    public static final int ERR_PARAM_VERIFICATION_CODE_INVALID = 261;

    public static final int ERR_DE_PL_NOT_EXIST = 300; // playlist not exist
    public static final int ERR_DE_PL_TYPE_NOT_EXIST = 301; // playlist type not exist
    public static final int ERR_PLN_VERSION_NOT_EXIST = 306;
    public static final int ERR_PLN_DELETED = 307;

    public static final int ERR_ARG_NULL_EX = 302;
    public static final int ERR_ARG_DECRYPT_EX = 303;
    public static final int ERR_ARG_DECRYPT_JSON_EX = 304;
    public static final int ERR_ARG_DECRYPT_SIGNATURE_EX = 305;

    public static final int ERR_USER_INVALID = 350;
    public static final int ERR_FAKE_USER = 3500;
    public static final int ERR_USER_WRONG_PWD = 351;
    public static final int ERR_USER_INVALID_CLIENT_ID = 352;
    public static final int ERR_USER_STATUS_IS_DISABLE = 353;
    public static final int ERR_USER_NOT_EXIST = 354;
    public static final int ERR_USER_DAC_FAILED = 355;
    public static final int ERR_USER_STATUS_IS_ABNORMAL = 356;
    public static final int ERR_USER_AUTO_ACTIVATE_DUPLICATED = 357;
    public static final int ERR_USER_AUTO_ACTIVATE_INVALID_CHANNEL_CONFIG = 358;
    public static final int ERR_USER_AUTO_ACTIVATE_INVALID_USERINFO = 359;

    public static final int ERR_UNSUPPORTED_VER = 400;
    public static final int ERR_UNSUPPORTED_TYPE = 401;

    public static final int ERR_CLOUD_NOT_REG = 500;
    public static final int ERR_CLOUD_INVALID_LOGIN_INFO = 501;
    public static final int ERR_CLOUD_USER_ERR = 502;
    public static final int ERR_CLOUD_NO_ACT_CODE = 503;
    public static final int ERR_CLOUD_INVALID_RES_PKG = 504;
    public static final int ERR_CLOUD_EXPIRED_RES_PKG = 505;
    public static final int ERR_CLOUD_REFRESH_OUT_OF_LIMIT = 506;
    public static final int ERR_CLOUD_REFRESH_DISABLE = 507;
    public static final int ERR_CLOUD_REFRESH_EXPIRED = 508;

    // 3.1
    // public static final int ERR_CLOUD_SHARE_REJECT = 509;
    public static final int ERR_CLOUD_SHARE_SELF_REJECT = 510;
    public static final int ERR_CLOUD_SHARE_BG_REJECT = 511;
    public static final int ERR_CLOUD_SHARE_TO_ACCOUNT_NOTFOUND = 512;

    public static final int ERR_CLOUD_SAVED_PACKAGE_FAILED = 3022;
    public static final int ERR_CLOUD_PARAM_INVALID_SITE_IS_NULL = 3023;
    public static final int ERR_CLOUD_PARAM_INVALID_ACCOUNT_IS_NULL = 3024;
    // public static final int ERR_CLOUD_REFRESH_OVER_LIMIT = 3025;
    // public static final int ERR_CLOUD_REFRESH_OFF = 3026;
    public static final int ERR_CLOUD_PACKAGE_INVALID = 3027;
    public static final int ERR_CLOUD_PACKAGE_UNPACK_FAILED = 3028;
    public static final int ERR_CLOUD_PACKAGE_TRANSFER_FAILED = 3029;
    public static final int ERR_CLOUD_PACKAGE_DECRYPT_FAILED = 3030;
    public static final int ERR_CLOUD_ACTIVATION_CODE_INVALID = 3031;
    public static final int ERR_CLOUD_PACKAGE_EXPIRED = 3032;
    public static final int ERR_CLOUD_ID_NOT_AUTHORIZED = 3033;
    public static final int ERR_CLOUD_PACKAGE_SAVED_FAILED = 3034;
    public static final int ERR_CLOUD_ACCOUNT_NOT_REGISTERED = 3035;
    public static final int ERR_CLOUD_PARAM_INVALID_CID_IS_NULL = 3036;
    public static final int ERR_CLOUD_PARAM_IN_PKG_REMOVE_FAILED = 3037;
    public static final int ERR_OAUTH_N_IS_EMPTY = 200;
    public static final int ERR_VER_IS_EMPTY = 601;
    public static final int ERR_UNSUPPORTED_VERSION = 602;
    public static final int ERR_USER_BIZ_EXPIRE = 800;
    public static final int ERR_USER_RETRY_REACH_MAX = 801;
    public static final int ERR_USER_INVALID_CHARGE_INFO = 802;
    public static final int ERR_USER_ALREADY_ACTIVE = 803;
    public static final int ERR_USER_CHARGE_SYSTEM_ERR = 804;
    public static final int ERR_USER_STATUS_IS_NON_ACTIVE = 805;
    public static final int ERR_USER_BIZ_IS_EMPTY = 806;
    public static final int ERR_USER_ILLEGAL_OPERATION = 807;
    public static final int ERR_USER_EMAIL_BINDING_ALREADY_ACTIVE = 808;
    public static final int ERR_USER_EMAIL_BINDING_EIXIST = 809;
    public static final int ERR_USER_EMAIL_BINDING_NOT_FOUND = 810;
    public static final int ERR_USER_EMAIL_BINDING_DATA_ERROR = 811;
    public static final int ERR_USER_GET_LOGIN_LINK_FAILURE = 812;
    public static final int ERR_USER_SERVICE_STATUS_UNKNOW = 813;
    public static final int ERR_PLAY_SERVICE_NOT_AVAIlABLE = 815;
    public static final int ERR_BIZ_IP_IS_NOT_AUTHORIZED = 901;
    public static final int ERR_BIZ_INVALID_SERVICE_TOKEN = 902;
    public static final int ERR_BIZ_EMPTY_SERVICE_TOKEN = 903;
    public static final int ERR_BIZ_ACTIVATION_FAILED = 904;
    public static final int ERR_ST_DECRYPT_FAILED = 905;
    public static final int ERR_ST_EMPTY_SERVICE_TOKEN = 906;
    public static final int ERR_ST_DID_ILLEGAL = 907;
    public static final int ERR_ST_ACT_CODE_INVALID = 908;
    public static final int ERR_EMAIL_DELIVERY_FAILED = 10001;
    public static final int ERR_EMAIL_INVALID = 10002;
    public static final int ERR_EMAIL_INVALID_ADDRESS = 10003;
    public static final int ERR_VERIFICATION_CODE_STORE_FAILED = 10004;
    public static final int ERR_SMS_MSG_LENGTH_OVER_LIMIT = 10005;
    public static final int ERR_SMS_SERVICE_NO_RESPONSE = 10006;
    public static final int ERR_VERIFICATION_CHANNEL_TYPE_UNSUPPORTED = 10007;
    public static final int ERR_AREA_ID_IS_EMPTY = 10008;
    public static final int ERR_SEND_VERIFICATION_FAILED = 10009;
    public static final int ERR_MUSES_DATABASE_ERROR = 10100;
    public static final int ERR_MUSES_DATA_NOT_EXIST = 10101;
    public static final int ERR_MUSES_DATA_ALREADY_EXIST = 10102;
    // Recharge card.
    public static final int ERR_RC_INVALID_ARGS = 20000; // Use recharge card with invalid args.
    public static final int ERR_RC_RECHARGE_FAILURE = 20001; // Use recharge card failure.
    public static final String MSG_NO_DATA = "No data found.";
    public static final String MSG_UNSUPPORTED_VERSION =
            "The current version is not supported. Please upgrade to the latest version.";
    public static final String MSG_UNSUPPORTED_VERSION_PT =
            "Este tipo não é compatível, faça atualização para a versão mais recente.";
    public static final String MSG_UNSUPPORTED_VERSION_ES =
            "Este tipo no es compatible, por favor actualiza a la última versión..";
    public static final int ERR_UC_EMAIL_IS_EMPTY = 1;
    public static final int ERR_UC_USER_NAME_IS_EMPTY = 2;
    public static final int ERR_UC_PASSWORD_IS_EMPTY = 3;
    public static final int ERR_UC_NAME_OR_PASSWORD_WRONG = 4;
    public static final int ERR_CODE_CLOUD_PWD_ERROR = 2010;
    public static final int ERR_SUB_ACCOUNT_IS_OVER_LIMIT = 30001;
    public static final int ERR_SUB_ACCOUNT_UPDATE_FAILED = 30002;
    public static final int ERR_SUB_ACCOUNT_NOT_EXIST = 30003;
    public static final int ERR_SUB_ACCOUNT_QUERY_FAILED = 30004;
    public static final int ERR_SUB_ACCOUNT_ADD_FAILED = 30005;
    public static final int ERR_ACCOUNT_BINDING_DATA_NOT_MATCHED = 40001;
    public static final int ERR_AUTH_OPERATION_NOT_SUPPORTED = 50001;
    public static int ERR_ACCOUNT_QUERY_ACCOUNT_FAILURE = 20001;
    public static int ERR_ACCOUNT_LOGIN_ACCOUNT_NOT_RESPONDING = 20002;
    public static int ERR_ACCOUNT_LOGIN_ACCOUNT_NO_RESULT = 20003;
    public static int ERR_CREATE_ACCOUNT_FAILED = 20004;
    public static int ERR_SYSTEM_CODE_NOT_FOUND = 20005;
    public static int ERR_ACCOUNT_CARD_NOT_FOUND = 20009;

    // HOT2.2
    public static int ERR_OAUTH_TOKEN_VERIFICATY_FAILED = 21001;
    public static int ERR_OAUTH_TOKEN_VERIFICATION_NO_RESULT = 21002;
    public static int ERR_OAUTH_SIGNATURE_VERIFICATY_FAILED = 21003;
    public static int ERR_OAUTH_UNSUPPORT_LOGIN_TYPE = 21004;
    public static int ERR_OAUTH_ACCESS_KEY_NOT_MATCH_MAC = 21005;
    public static int ERR_OAUTH_TOKEN_VERIFICATY_NO_RESPONSE = 21006;
    public static int ERR_OAUTH_TOKEN_GET_FAILED = 21007;

    public static int ERR_PUSH_FAILED = 21008;
}

==> vod-api-model-3.0.0-sources.jar: com/valor/vod/api/model/constant/response/HttpCode2.java <==
package com.valor.vod.api.model.constant.response;

/**
 * mfc vms http status code Created by Frank.Huang on 2016/7/5.
 */
public class HttpCode2 {

    //return http code
    public static final int SERVER_ERROR = 555; // Server error

    public static final int SYS_CODE_AUTH = 2;
    public static final int SYS_CODE_META = 1001;
    public static final int SYS_CODE_CLOUD = 1002;
    public static final int SYS_CODE_ACCOUNT = 1003;

    public static final int SYS_CODE_PROFILE = 1005;
    public static final int SYS_CODE_CC = 1006;
    public static final int SYS_CODE_CLOUD_PKG_WEB = 1007;
    public static final int SYS_CODE_FLOW_CONTROL = 1008;
    public static final int SYS_CODE_DAC = 1009;
    public static final int SYS_CODE_LAC = 1010;
    public static final int SYS_CODE_MEMBER_WEB = 1011;
    public static final int SYS_CODE_ADMIN_SERVER = 1012;
    public static final int SYS_CODE_ACTIVITY = 1013;

    public static final int SYS_CODE_OAUTH2_SERVER = 2000;

    public static final int OK = 0;

    public static final int RET_SYS_EXCEPTION = 1;  //系统异常
    public static final int RET_UNAUTHORIZED = 2;  //未授权
    public static final int RET_INVALID_PARAM = 3;  //无效的参数
    public static final int RET_DATA_EXCEPTION = 4;  //数据异常
    public static final int RET_INVALID_USER = 5;  //无效的用户
    public static final int RET_UNSUPPORTED_VERSION = 6;  //不支持的版本
    public static final int RET_CLOUD_ERR = 7;  //网盘操作错误
    public static final int RET_USER_BIZ = 8;  //用户业务
    public static final int RET_BIZ_ERR = 9;  //业务
    public static final int RET_UC_USER = 10;

    //error code
    public static final int ERR_NO_DATA = 100;
    public static final int ERR_SYS_EXCEPTION = 101;
    public static final int ERR_INVALID_USER = 102;
    public static final int ERR_RESULT_NOT_UNIQUE = 103;
    public static final int ERR_ES_EXCEPTION = 104;
    public static final int ERR_ENCRYPT_MSG = 105;
    public static final int ERR_CALL_API_ERROR = 106;//调用API接口失败
    public static final int ERR_SYS_SERVICE_NOTAVALIABLE = 107;
    public static final int ERR_SYS_IO_EXCEPTION = 108;
    public static final int ERR_SYS_API_ERROR = 109;

    public static final int ERR_AUTH_TOKEN_IS_EMPTY = 200;
    public static final int ERR_AUTH_INVALID_TOKEN = 201;
    public static final int ERR_AUTH_INVALID_DID = 202;
    public static final int ERR_AUTH_EXPIRED_TOKEN = 203;
    public static final int ERR_AUTH_UNREGISTERED_DID = 204;
    public static final int ERR_AUTH_UID_CONFLICT = 205;
    public static final int ERR_AUTH_USER_STATUS_EXCEPTION = 206;
    public static final int ERR_AUTH_INVALID_AS_PRIVATE_KEY = 207;
    public static final int ERR_AUTH_INVALID_TOKEN_TO_OBJECT = 208;
    public static final int ERR_AUTH_INVALID_APPID = 220;
    public static final int ERR_AUTH_INVALID_APPVER = 221;
    public static final int ERR_AUTH_DID_LOGIN_DISABLE = 222;
    public static final int ERR_AUTH_ACCOUNT_ID_CONFLICT = 223;
    public static final int ERR_AUTH_REGION_FORBIDDEN = 224;
    public static final int ERR_AUTH_CURRENT_ACCOUNT_ALREADY_OFFLINE = 225;//当前用户已下线
    public static final int ERR_AUTH_QUERY_LOGIN_METHOD_FAILURE = 226;//
    public static final int ERR_AUTH_LOGIN_CODE_ALREADY_USED = 227;//
    public static final int ERR_AUTH_LOGIN_DEVICE_UNAUTHORIZED = 228;//

    public static final int ERR_EMAIL_BINDING_FAILED = 230;

    public static final int ERR_AUTH_VERIFICATION_CODE_IS_EMPTY = 240;
    public static final int ERR_AUTH_INVALID_PHONE_NUMBER = 241;
    public static final int ERR_AUTH_PHONE_NUMBER_IS_EMPTY = 242;


    public static final int ERR_PARAM_INVALID = 250;
    public static final int ERR_PARAM_ID_IS_EMPTY = 251;
    public static final int ERR_PARAM_UPLOAD_ERROR = 252;


    public static final int ERR_PARAM_UNSUPPORTED_CHANNEL_ERROR = 260;
    public static final int ERR_PARAM_VERIFICATION_CODE_INVALID = 261;

    public static final int ERR_DE_PL_NOT_EXIST = 300; //playlist not exist
    public static final int ERR_DE_PL_TYPE_NOT_EXIST = 301; //playlist type not exist

    public static final int ERR_ARG_NULL_EX = 302;
    public static final int ERR_ARG_DECRYPT_EX = 303;
    public static final int ERR_ARG_DECRYPT_JSON_EX = 304;
    public static final int ERR_ARG_DECRYPT_SIGNATURE_EX = 305;


    public static final int ERR_USER_INVALID = 350;
    public static final int ERR_FAKE_USER = 3500;
    public static final int ERR_USER_WRONG_PWD = 351;
    public static final int ERR_USER_INVALID_CLIENT_ID = 352;
    public static final int ERR_USER_STATUS_IS_DISABLE = 353;
    public static final int ERR_USER_NOT_EXIST = 354;
    public static final int ERR_USER_DAC_FAILED = 355;
    public static final int ERR_USER_STATUS_IS_ABNORMAL = 356;
    public static final int ERR_USER_AUTO_ACTIVATE_DUPLICATED = 357;


    public static final int ERR_UNSUPPORTED_VER = 400;
    public static final int ERR_UNSUPPORTED_TYPE = 401;

    public static final int ERR_CLOUD_NOT_REG = 500;
    public static final int ERR_CLOUD_INVALID_LOGIN_INFO = 501;
    public static final int ERR_CLOUD_USER_ERR = 502;
    public static final int ERR_CLOUD_NO_ACT_CODE = 503;
    public static final int ERR_CLOUD_INVALID_RES_PKG = 504;
    public static final int ERR_CLOUD_EXPIRED_RES_PKG = 505;
    public static final int ERR_CLOUD_REFRESH_OUT_OF_LIMIT = 506;
    public static final int ERR_CLOUD_REFRESH_DISABLE = 507;
    public static final int ERR_CLOUD_REFRESH_EXPIRED = 508;


    public static final int ERR_CLOUD_SAVED_PACKAGE_FAILED = 3022;
    public static final int ERR_CLOUD_PARAM_INVALID_SITE_IS_NULL = 3023;
    public static final int ERR_CLOUD_PARAM_INVALID_ACCOUNT_IS_NULL = 3024;
    // public static final int ERR_CLOUD_REFRESH_OVER_LIMIT = 3025;
    // public static final int ERR_CLOUD_REFRESH_OFF = 3026;
    public static final int ERR_CLOUD_PACKAGE_INVALID = 3027;
    public static final int ERR_CLOUD_PACKAGE_UNPACK_FAILED = 3028;
    public static final int ERR_CLOUD_PACKAGE_TRANSFER_FAILED = 3029;
    public static final int ERR_CLOUD_PACKAGE_DECRYPT_FAILED = 3030;
    public static final int ERR_CLOUD_ACTIVATION_CODE_INVALID = 3031;
    public static final int ERR_CLOUD_PACKAGE_EXPIRED = 3032;
    public static final int ERR_CLOUD_ID_NOT_AUTHORIZED = 3033;
    public static final int ERR_CLOUD_PACKAGE_SAVED_FAILED = 3034;
    public static final int ERR_CLOUD_ACCOUNT_NOT_REGISTERED = 3035;
    public static final int ERR_CLOUD_PARAM_INVALID_CID_IS_NULL = 3036;
    public static final int ERR_OAUTH_N_IS_EMPTY = 200;
    public static final int ERR_VER_IS_EMPTY = 601;
    public static final int ERR_UNSUPPORTED_VERSION = 602;
    public static final int ERR_USER_BIZ_EXPIRE = 800;
    public static final int ERR_USER_RETRY_REACH_MAX = 801;
    public static final int ERR_USER_INVALID_CHARGE_INFO = 802;
    public static final int ERR_USER_ALREADY_ACTIVE = 803;
    public static final int ERR_USER_CHARGE_SYSTEM_ERR = 804;
    public static final int ERR_USER_STATUS_IS_NON_ACTIVE = 805;
    public static final int ERR_USER_BIZ_IS_EMPTY = 806;
    public static final int ERR_USER_ILLEGAL_OPERATION = 807;
    public static final int ERR_USER_EMAIL_BINDING_ALREADY_ACTIVE = 808;
    public static final int ERR_USER_EMAIL_BINDING_EIXIST = 809;
    public static final int ERR_USER_EMAIL_BINDING_NOT_FOUND = 810;
    public static final int ERR_USER_EMAIL_BINDING_DATA_ERROR = 811;
    public static final int ERR_USER_GET_LOGIN_LINK_FAILURE = 812;
    public static final int ERR_USER_SERVICE_STATUS_UNKNOW = 813;
    public static final int ERR_PLAY_SERVICE_NOT_AVAIlABLE = 815;
    public static final int ERR_BIZ_IP_IS_NOT_AUTHORIZED = 901;
    public static final int ERR_BIZ_INVALID_SERVICE_TOKEN = 902;
    public static final int ERR_BIZ_EMPTY_SERVICE_TOKEN = 903;
    public static final int ERR_BIZ_ACTIVATION_FAILED = 904;
    public static final int ERR_ST_DECRYPT_FAILED = 905;
    public static final int ERR_ST_EMPTY_SERVICE_TOKEN = 906;
    public static final int ERR_ST_DID_ILLEGAL = 907;
    public static final int ERR_ST_ACT_CODE_INVALID = 908;
    public static final int ERR_EMAIL_DELIVERY_FAILED = 10001;
    public static final int ERR_EMAIL_INVALID = 10002;
    public static final int ERR_EMAIL_INVALID_ADDRESS = 10003;
    public static final int ERR_VERIFICATION_CODE_STORE_FAILED = 10004;
    public static final int ERR_SMS_MSG_LENGTH_OVER_LIMIT = 10005;
    public static final int ERR_SMS_SERVICE_NO_RESPONSE = 10006;
    public static final int ERR_VERIFICATION_CHANNEL_TYPE_UNSUPPORTED = 10007;
    public static final int ERR_AREA_ID_IS_EMPTY = 10008;
    public static final int ERR_SEND_VERIFICATION_FAILED = 10009;
    //Recharge card.
    public static final int ERR_RC_INVALID_ARGS = 20000;//Use recharge card with invalid args.
    public static final int ERR_RC_RECHARGE_FAILURE = 20001;//Use recharge card failure.
    public static final String MSG_NO_DATA = "No data found.";
    public static final String MSG_UNSUPPORTED_VERSION = "The current version is not supported. Please upgrade to the latest version.";
    public static final String MSG_UNSUPPORTED_VERSION_PT = "Este tipo não é compatível, faça atualização para a versão mais recente.";
    public static final String MSG_UNSUPPORTED_VERSION_ES = "Este tipo no es compatible, por favor actualiza a la última versión..";
    public static final int ERR_UC_EMAIL_IS_EMPTY = 1;
    public static final int ERR_UC_USER_NAME_IS_EMPTY = 2;
    public static final int ERR_UC_PASSWORD_IS_EMPTY = 3;
    public static final int ERR_UC_NAME_OR_PASSWORD_WRONG = 4;
    public static final int ERR_SUB_ACCOUNT_IS_OVER_LIMIT = 30001;
    public static final int ERR_SUB_ACCOUNT_UPDATE_FAILED = 30002;
    public static final int ERR_SUB_ACCOUNT_NOT_EXIST = 30003;
    public static final int ERR_SUB_ACCOUNT_QUERY_FAILED = 30004;
    public static final int ERR_SUB_ACCOUNT_ADD_FAILED = 30005;
    public static final int ERR_ACCOUNT_BINDING_DATA_NOT_MATCHED = 40001;
    public static final int ERR_AUTH_OPERATION_NOT_SUPPORTED = 50001;
    public static int ERR_ACCOUNT_QUERY_ACCOUNT_FAILURE = 20001;
    public static int ERR_ACCOUNT_LOGIN_ACCOUNT_NOT_RESPONDING = 20002;
    public static int ERR_ACCOUNT_LOGIN_ACCOUNT_NO_RESULT = 20003;
    public static int ERR_CREATE_ACCOUNT_FAILED = 20004;
    public static int ERR_SYSTEM_CODE_NOT_FOUND = 20005;

    //HOT2.2
    public static int ERR_OAUTH_TOKEN_VERIFICATY_FAILED = 21001;
    public static int ERR_OAUTH_TOKEN_VERIFICATION_NO_RESULT = 21002;
    public static int ERR_OAUTH_SIGNATURE_VERIFICATY_FAILED = 21003;
    public static int ERR_OAUTH_UNSUPPORT_LOGIN_TYPE = 21004;
    public static int ERR_OAUTH_ACCESS_KEY_NOT_MATCH_MAC = 21005;
    public static int ERR_OAUTH_TOKEN_VERIFICATY_NO_RESPONSE = 21006;


}
